convtools package
=================

Submodules
----------

convtools.aggregations module
-----------------------------

.. automodule:: convtools.aggregations
   :members:
   :undoc-members:
   :show-inheritance:

convtools.base module
---------------------

.. automodule:: convtools.base
   :members:
   :undoc-members:
   :show-inheritance:

convtools.conversion module
---------------------------

.. automodule:: convtools.conversion
   :members:
   :undoc-members:
   :show-inheritance:

convtools.joins module
----------------------

.. automodule:: convtools.joins
   :members:
   :undoc-members:
   :show-inheritance:

convtools.utils module
----------------------

.. automodule:: convtools.utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: convtools
   :members:
   :undoc-members:
   :show-inheritance:
